function [E]=AnalyzeLoadingData(data_filename,Area)

%Read BIN file
if(isempty(data_filename))%no file specified
    [file,path]=uigetfile('*.bin');
    data_filename=fullfile(path,file);
end
[t,x,F,Photo,Contact,Loading,Unloading,Pulloff]=ReduceData(data_filename,7);

%Parse loading channel
[y_out,rising_edges,falling_edges]=AnalyzeOneBinaryChannel(Loading);

if(~any(y_out))%No loading data found!
    E=NaN;
else
    %Get first loading data (u,F)
    x_data=x(y_out==1);
    F_data=F(y_out==1);
    u_data=x_data(1)-x_data;
    
    if(~isempty(Area))%right prism/cylinder
        L=x_data(1);%unloaded height
        [E,F_fit]=CylinderModulus(u_data,F_data,Area,L);
    else%sphere
        %Fit Hertz Model
        R=x_data(1)/2;%estimate radius from height - assume spherical sample
        [E,F_fit]=HertzModulus(u_data,F_data,R);
    end
    
    %Make a stacked plot - helpful for debugging
    figure;
    tbl=table(t,x,F,Photo,Contact,Loading,Unloading,Pulloff);
    stackedplot(tbl);
    
    %Output fit and modulus value to a new figure
    figure;
    plot(u_data*1e3,F_data*1e3,'k.',u_data*1e3,F_fit*1e3,'r-','LineWidth',1.5);
    xlabel('Compression (mm)');
    ylabel('Applied Load (mN)');
    grid on;
    legend({'Data','Hertz Model'},'Location','NW');
    title(['E=',num2str(E,'%11.4g')]);

    %% Plot the loading history only - useful for publication
    idx=find(Contact>0.5,1,'first')+1;
    Time=t(idx:end)-t(idx);
    Displacement=1e3*(x(idx)-x(idx:end));
    Load=1e3*(F(idx:end)-F(idx));
    figure;
    axes('FontName','Arial','FontSize',14,'LineWidth',1.5);
    subplot(2,1,1);plot(Time,Displacement,'b-','LineWidth',1.5);xlabel('Time (s)');ylabel('Displacement (mm)');%ylim([-0.1 1.2]);
    subplot(2,1,2);plot(Time,Load,'b-','LineWidth',1.5);xlabel('Time (s)');ylabel('Load (mN)');%ylim([-10 75])

end
