function [prog_out]=MeasureForce(app,prog_in)
%% Use a single pole low-pass filter with normalized weight k1 applied to the newest datapoint.

LoadCell_Capacity=app.LoadCell_Capacity;
LoadCell_ADCRange=app.LoadCell_ADCRange;
LoadCell_Sensitivity=app.LoadCell_Calibration_Coefficients_Sensitivity;
LoadCell_Offset=app.LoadCell_Calibration_Coefficients_Offset;
LoadCell_FilterGain=app.LoadCell_FilterGain;

force_prog_init=sprintf([ 'XQ#force,1;WT1000\r']);%wait 1 second to initialize force offset

%% Set max voltage for load cell safety program
switch(LoadCell_ADCRange)
    case(1),v_max=5;v_min=-5;
    case(2),v_max=10;v_min=-10;
    case(3),v_max=5;v_min=0;
    case(4),v_max=10;v_min=0;
end

ForceCutoff=LoadCell_Capacity;

voltstr='v=@AN[1]-@AN[2]\r';%differential input

if(abs(ForceCutoff)<(LoadCell_Sensitivity*v_max))%if max force is less than equivalent overvoltage
    CheckForOverload=sprintf([  'IF(@ABS[force]>fmax);',...
                                'FL_TPA;MG"OVERLOAD";',...%Set forward software limit switch, then send a warning message to MATLAB
                                'ENDIF\r']);
    limits=sprintf(['fmax=',num2str(ForceCutoff),'\r']);%N of force above/below which motor will shut off
else%keep checking to make sure load cell voltage is in range
    CheckForOverload=sprintf([  'IF((v<vmin)|(v>vmax));',...
                                'AB0;MG"WARNING_VOLTAGE";',...%stop everything and shut off motor, then send a warning message to MATLAB
                                'ENDIF\r']);
    limits=sprintf(['vmax=',num2str(v_max),'\r',...%voltage limit (compression)
                    'vmin=',num2str(v_min),'\r']);%undervoltage limit (tension)
end

%% Set the offset force
ForceProg=sprintf([ '\r#force\r',...%set the force offset by averaging before movement starts
                    'b1=',num2str(LoadCell_Offset),'\r',...
                    'b2=',num2str(LoadCell_Sensitivity),'\r',...
                    limits,...
                    'k1=',num2str(LoadCell_FilterGain),'\r',...%these can be updated dynamically by sending the command k1=xxx;k2=1-k1
                    'k2=1-k1\r',...
                    voltstr,...%start the initialization process
                    'f0=v/b2\r',...
                    'find=0\r',...
                    '#initf\r',...%estimate the initial force offset
                    voltstr,...
                    'f0=(k1*v/b2)+(k2*f0)\r',...
                    'find=find+1\r',...
                    'JP#initf,find<1000\r',...%filter 1000 times to ensure good baseline reading
                    voltstr,...%start computing filtered force
                    'force=v/b2\r',...
                    CheckForOverload,...
                    '#ffilt\r',...
                    voltstr,...%assign load cell voltage to variable (allows safety program)
                    'force=(k1*v/b2)+(k2*force)\r',...
                    CheckForOverload,...
                    'ZAA=(force-f0)*1000000\r',...%offset and convert to microN
                    'JP#ffilt\r',...
                    'EN\r\r']);


%% Append the #force progrma and add a line to start it executing
prog_out=sprintf([force_prog_init,...
                    prog_in,...%this 
                    ForceProg]);
                    
