function [t,u,F,Photo,Contact,Loading,Unloading,Pulloff]=ReduceData(data_filename,NumChannels)

%% Get the data from the binary file
fid=fopen(data_filename);
fseek(fid,0,'eof');%go to end of file
idx=ftell(fid);%count number of bytes
frewind(fid);%go back to start of file
data=fread(fid,[NumChannels idx/(8*NumChannels)],'double');%,[1 idx/8],'double');
fclose(fid);

%% Data recorded as follows:
%% data=[time pos Force TEMP Photo InContact];
data=data';

t0=data(:,1);
pos=data(:,2);
force=data(:,3);

% figure;stackedplot(data);
if(NumChannels==8)%include temperature - not differential force
    T=data(:,4);
    Photo=data(:,5);
    Contact=data(:,6);
    Loading=data(:,7);
    Unloading=data(:,8);
elseif(NumChannels==7)%differential force - no room to measure temperature
    T=[];%not measured when both analog inputs are used for differential load cell amplifier readings
    Photo=data(:,4);%set while shutter is open
    Contact=data(:,5);%set while in contact (until pull-off is complete, so no rigorous un-setting)
    Loading=data(:,6);%set while loading (and pull-off)
    Unloading=data(:,7);%set while unloading (and pull-off)
end
Pulloff=(Loading & Unloading);%both are set during pulloff
Loading=(Loading & ~Pulloff);%delete pulloff points from loading
Unloading=(Unloading & ~Pulloff);%delete pulloff points from unloading

dt=diff(t0);

%% Account for time wrapping
idx=[find(dt<0)];
if(~isempty(idx))
    time=zeros(size(t0));
    time(1:idx(1))=t0(1:idx(1))-t0(1);
    for(i=1:length(idx)-1)
        time(idx(i)+1:idx(i+1))=time(idx(i))+t0(idx(i)+1:idx(i+1));
    end
    time(idx(end)+1:end)=time(idx(end))+t0(idx(end)+1:end);
else
    time=t0-t0(1);
end

%% Compute relative values in SI units
t=ComputeTrueTime(time-time(1))/1e3;%account for Galil short clock - us to s
u=-CountsToMicrons(pos)*1e-6;%counts to microns to meters
F=force-mean(force(1:10));%force is now already in Newtons

